@@ -1,3 +1,5 @@
+use strict;
+
 # These variables will be auto-created with absolute paths on installation
 # For now, I give them decent default values.
 
@@ -10,7 +12,6 @@ my $symbolname = 'PQT_boot_Qt';
 
     $DynaLoader::dl_debug = $ENV{'PERL_DL_DEBUG'} || 0;
     boot_DynaLoader('DynaLoader') if defined &boot_DynaLoader;
-    { local $^W = 0; *boot_DynaLoader = sub {} }
 
     $handle = dl_load_file($file, 0) || die dl_error();
     $symbol = dl_find_symbol($handle, $symbolname) || die dl_error();
