@@ -237,20 +237,6 @@ double pqt_argument_double(double pqt1) {
     return pqtr;
 }
 
-float pqt_argument_float() {
-    PQT_dXSARGS;
-    float pqtr = (float)SvNV(PQT_GOODST);
-    pqtindex++;
-    return pqtr;
-}
-
-float pqt_argument_float(float pqt1) {
-    PQT_dXSARGS;
-    float pqtr = PQT_IFARG((float)SvNV(PQT_ST));
-    pqtindex++;
-    return pqtr;
-}
-
 bool pqt_argument_bool() {
     PQT_dXSARGS;
     bool pqtr = SvTRUE(PQT_GOODST) ? TRUE : FALSE;
@@ -293,14 +279,6 @@ char pqt_argument_char(char pqt1) {
     return pqtr;
 }
 
-const char **pqt_argument_internal(const char **) {
-    return 0;
-}
-
-bool *pqt_argument_boolptr(bool *pqt1) {
-    return pqt1;
-}
-
 pqt_object_data *pqt_extract_object(SV *pqt1) {
     if(!SvROK(pqt1)) return 0;
     HV *pqthv_obj = (HV *)SvRV(pqt1);
@@ -393,7 +371,7 @@ void *pqt_argument_class_destructor(const char *pqt1) {
         return (void *)SvIV(&sv_undef);
     pqt_object_data *pqtd = pqt_extract_object(PQT_ST);
     pqtindex++;
-    return pqtd->pqtptr;
+    return pqt_cast_object(pqtd, pqt1);
 }
 
 void *pqt_argument_classref(const char *pqt1) {
@@ -670,10 +648,6 @@ void pqt_lastargument() {
 void pqt_destroy_object(void *, class pqt_virtual *) {
 }
 
-void pqt_ambiguous(const char *pqt1, const char *pqt2) {
-    die("Ambiguous call to %s::%s", pqt1, pqt2);
-}
-
 bool pqt_can_delete() {
     PQT_uXSARGS;
     pqt_object_data *pqtd = pqt_extract_object(ST(0));
