@@ -1,7 +1,6 @@
 package CannonField;
 
-use Qt;
-use QWidget;
+use Qt ();
 
 use signals 'angleChanged(int)';
 use slots 'setAngle(int)';
@@ -11,7 +10,7 @@ use slots 'setAngle(int)';
 sub new {
     my $self = shift->SUPER::new(@_);
 
-    $$self{'ang'} = 45;
+    $self->{'ang'} = 45;
     return $self;
 }
 
@@ -23,14 +22,14 @@ sub setAngle {
 
     $degrees = 5 if $degrees < 5;
     $degrees = 70 if $degrees > 70;
-    return if $$self{'ang'} == $degrees;
-    $$self{'ang'} = $degrees;
+    return if $self->{'ang'} == $degrees;
+    $self->{'ang'} = $degrees;
     $self->repaint();
-    emit $self->angleChanged($$self{'ang'});
+    emit $self->angleChanged($self->{'ang'});
 }
 
 sub paintEvent {
     my $self = shift;
 
-    $self->drawText(200, 100, "Angle = $$self{'ang'}");
+    $self->drawText(200, 100, "Angle = $self->{'ang'}");
 }
